@@ -1,25 +1,28 @@
+package Sys::HostIP;
+$Sys::HostIP::VERSION = '2.100';
+# ABSTRACT: Try extra hard to get IP address related info
+
 use strict;
 use warnings;
-package Sys::HostIP;
-# ABSTRACT: Try extra hard to get IP address related info
-$Sys::HostIP::VERSION = '2.000';
+
 use Carp;
 use Exporter;
 use File::Basename 'dirname';
-use vars qw( @ISA @EXPORT_OK );
+use parent 'Exporter';
 
-@ISA       = qw(Exporter);
-@EXPORT_OK = qw( ip ips interfaces ifconfig );
+our @EXPORT_OK = qw( ip ips interfaces ifconfig );
 
-my $is_win = $^O =~ qr/(MSWin32|cygwin)/;
+our $IS_WIN = $^O =~ qr/(MSWin32|cygwin)/xms; ## no critic qw(Variables::ProhibitPunctuationVars)
 
-sub new {
-    my $class = shift || croak 'Cannot create new method in a functional way';
-    my %opts  = @_;
-    my $self  = bless {%opts}, $class;
+sub new { ## no critic qw(Subroutines::RequireArgUnpacking)
+    my $class = shift
+        or croak 'Cannot create new method in a functional way';
+
+    my %opts = @_;
+    my $self = bless {%opts}, $class;
 
     # only get ifconfig binary if it's not a windows
-    $self->{'ifconfig'} ||= $is_win ? '' : $self->_get_ifconfig_binary;
+    $self->{'ifconfig'} ||= $IS_WIN ? '' : $self->_get_ifconfig_binary;
     $self->{'if_info'}  ||= $self->_get_interface_info;
 
     return $self;
@@ -29,7 +32,7 @@ sub ifconfig {
     my $self = shift;
     my $path = shift;
 
-    if ( ! ref $self ) {
+    if ( !ref $self ) {
         return $self->_get_ifconfig_binary;
     }
 
@@ -43,23 +46,20 @@ sub ip {
     my $self = shift || 'Sys::HostIP';
     my $if_info;
 
-    if ( ! ref $self ) {
+    if ( !ref $self ) {
         $if_info = $self->_get_interface_info;
     } else {
         $if_info = $self->if_info;
     }
 
-    if ($is_win) {
-        foreach my $key ( sort keys %{$if_info} ) {
-            # should this be the default?
-            if ( $key =~ /Local Area Connection/ ) {
-                return ( $if_info->{$key} );
-            }
-        }
+    if ($IS_WIN) {
+        my @if_keys = sort keys %{$if_info};
+        return ( $if_info->{ $if_keys[0] } );
     } else {
         my $lo_found;
 
         foreach my $key ( sort keys %{$if_info} ) {
+
             # we don't want the loopback
             if ( $if_info->{$key} eq '127.0.0.1' ) {
                 $lo_found++;
@@ -80,7 +80,7 @@ sub ip {
 sub ips {
     my $self = shift || 'Sys::HostIP';
 
-    if ( ! ref $self ) {
+    if ( !ref $self ) {
         return [ values %{ $self->_get_interface_info } ];
     }
 
@@ -90,20 +90,16 @@ sub ips {
 sub interfaces {
     my $self = shift || 'Sys::HostIP';
 
-    if ( ! ref $self ) {
+    if ( !ref $self ) {
         return $self->_get_interface_info;
     }
 
-   return $self->if_info;
+    return $self->if_info;
 }
 
 sub if_info {
     my $self = shift;
 
-    if ( ! ref $self ) {
-        return $self->_get_ifconfig_binary;
-    }
-
     return $self->{'if_info'};
 }
 
@@ -111,8 +107,9 @@ sub _get_ifconfig_binary {
     my $self     = shift;
     my $ifconfig = '/sbin/ifconfig -a';
 
-    if ( $^O =~ /(?: linux|openbsd|freebsd|netbsd|solaris|darwin )/xi ) {
-        $ifconfig =  '/sbin/ifconfig -a';
+    ## no critic qw(Variables::ProhibitPunctuationVars)
+    if ( $^O =~ /(?: linux|openbsd|freebsd|netbsd|solaris|darwin )/xmsi ) {
+        $ifconfig = '/sbin/ifconfig -a';
     } elsif ( $^O eq 'aix' ) {
         $ifconfig = '/usr/sbin/ifconfig -a';
     } elsif ( $^O eq 'irix' ) {
@@ -120,28 +117,32 @@ sub _get_ifconfig_binary {
     } elsif ( $^O eq 'dec_osf' ) {
         $ifconfig = '/sbin/ifconfig';
     } else {
-        carp "Unknown system ($^O), guessing ifconfig is in /sbin/ifconfig " .
-             "(email xsawyerx\@cpan.org with the location of your ifconfig)\n";
+        carp "Unknown system ($^O), guessing ifconfig is in /sbin/ifconfig "
+            . "(email xsawyerx\@cpan.org with the location of your ifconfig)\n";
     }
 
     return $ifconfig;
 }
 
 sub _get_interface_info {
-    my $self    = shift;
-    my $if_info = $is_win                            ?
-                  $self->_get_win32_interface_info() :
-                  $self->_get_unix_interface_info();
+    my $self = shift;
+
+    return $IS_WIN
+        ? $self->_get_win32_interface_info()
+        : $self->_get_unix_interface_info();
 }
 
 sub _clean_ifconfig_env {
     my $self = shift;
+
     # this is an attempt to fix tainting problems
 
     # removing $BASH_ENV, which exists if /bin/sh is your bash
     delete $ENV{'BASH_ENV'};
 
     # now we set the local $ENV{'PATH'} to be only the path to ifconfig
+    # We have localized %ENV in the call to this, so we disable critic warning
+    ## no critic qw(Variables::RequireLocalizedPunctuationVars)
     my $ifconfig = $self->ifconfig;
     $ENV{'PATH'} = dirname $ifconfig;
 
@@ -164,6 +165,7 @@ sub _get_unix_interface_info {
     my @ifconfig     = `$ifconfig_bin`;
 
     foreach my $line (@ifconfig) {
+
         # TODO: refactor this into tests
         # output from 'ifconfig -a' looks something like this on every *nix i
         # could get my hand on except linux (this one's actually from OpenBSD):
@@ -200,29 +202,35 @@ sub _get_unix_interface_info {
         # letters followed (possibly) by an number and a colon, then we've got an
         # interface. if the line starts with a space, then it's the info from the
         # interface that we just found, and we stick the contents into %if_info
-        if ( ($line =~/^\s+/) && ($interface) ) {
+        if ( ( $line =~ /^\s+/ ) && ($interface) ) {
             $if_info{$interface} .= $line;
         }
+
         # FIXME: refactor this regex
-        elsif (($interface) = ($line =~/(^\w+(?:\d)?(?:\.\d+)?(?:\:\d+)?)/)) {
-            $line =~s/\w+\d(\:)?\s+//;
+        elsif ( ($interface)
+            = ( $line =~ /(^\w+(?:\d)?(?:\.\d+)?(?:\:\d+)?)/ ) )
+        {
+            $line =~ s/\w+\d(\:)?\s+//;
             $if_info{$interface} = $line;
         }
     }
 
-    foreach my $key (keys %if_info) {
+    foreach my $key ( keys %if_info ) {
+
         # now we want to get rid of all the other crap in the ifconfig
         # output. we just want the ip address. perhaps a future version can
         # return even more useful results (netmask, etc).....
-        if (my ($ip) = ($if_info{$key} =~/inet (?:addr\:)?(\d+(?:\.\d+){3})/)) {
+        if ( my ($ip)
+            = ( $if_info{$key} =~ /inet (?:addr\:)?(\d+(?:\.\d+){3})/ ) )
+        {
             $if_info{$key} = $ip;
-        }
-        else {
-          # ok, no ip address here, which means this interface isn't
-          # active. some os's (openbsd for instance) spit out ifconfig info for
-          # inactive devices. this is pretty much worthless for us, so we
-          # delete it from the hash
-         delete $if_info{$key};
+        } else {
+
+            # ok, no ip address here, which means this interface isn't
+            # active. some os's (openbsd for instance) spit out ifconfig info for
+            # inactive devices. this is pretty much worthless for us, so we
+            # delete it from the hash
+            delete $if_info{$key};
         }
     }
 
@@ -260,10 +268,11 @@ sub _get_win32_interface_info {
     foreach my $line (@ipconfig) {
         chomp($line);
 
-        if ( $line =~ /Windows/ ) {
+        if ( $line =~ /Windows/xms ) {
+
             # ignore the header
             next;
-        } elsif ( $line =~/^\s$/ ) {
+        } elsif ( $line =~ /^\s$/xms ) {
             next;
         } elsif ( ( $line =~ $regexes{'address'} ) and defined $interface ) {
             $if_info{$interface} = $1;
@@ -271,7 +280,7 @@ sub _get_win32_interface_info {
         } elsif ( $line =~ $regexes{'adapter'} ) {
             $interface = $1;
             chomp $interface;
-            $interface =~ s/\s+$//g;  # remove trailing whitespace, if any
+            $interface =~ s/\s+$//gxms; # remove trailing whitespace, if any
         }
     }
 
@@ -389,7 +398,8 @@ All of these subroutines will match the object oriented interface methods.
 
 Originally written by Jonathan Schatz <bluelines@divisionbyzero.com>.
 
-Currently maintained by Sawyer X <xsawyerx@cpan.org>.
+Currently maintained by Paul Cochrane <paul@liekut.de> and Sawyer X
+<xsawyerx@cpan.org>.
 
 =head1 TODO
 
